@@ -2,25 +2,21 @@ use std::collections::HashMap;
 use std::sync::Arc;
 use std::time::Duration;
 
+use crate::command::{
+    parse, Command, GotoMode, JumpMode, MoveAmount, MoveMode, SeekDirection, ShiftMode, TargetMode,
+};
 use crate::config::Config;
 use crate::events::EventManager;
 use crate::library::Library;
 use crate::queue::{Queue, RepeatSetting};
 use crate::spotify::{Spotify, VOLUME_PERCENT};
 use crate::traits::{IntoBoxedViewExt, ViewExt};
-use crate::ui::contextmenu::ContextMenu;
+use crate::ui::contextmenu::{AddToPlaylistMenu, ContextMenu, SelectArtistMenu};
 use crate::ui::help::HelpView;
 use crate::ui::layout::Layout;
 use crate::ui::modal::Modal;
 use crate::ui::search_results::SearchResultsView;
 use crate::UserData;
-use crate::{
-    command::{
-        parse, Command, GotoMode, JumpMode, MoveAmount, MoveMode, SeekDirection, ShiftMode,
-        TargetMode,
-    },
-    ui::contextmenu::AddToPlaylistMenu,
-};
 use cursive::event::{Event, Key};
 use cursive::traits::View;
 use cursive::views::Dialog;
@@ -273,6 +269,8 @@ impl CommandManager {
             contextmenu.on_command(s, cmd)?
         } else if let Some(mut add_track_menu) = s.find_name::<AddToPlaylistMenu>("addtrackmenu") {
             add_track_menu.on_command(s, cmd)?
+        } else if let Some(mut select_artist) = s.find_name::<SelectArtistMenu>("selectartist") {
+            select_artist.on_command(s, cmd)?
         } else {
             let mut main = s
                 .find_name::<Layout>("main")
