@@ -11,6 +11,7 @@ use std::str::FromStr;
 use std::sync::Arc;
 
 use clap::{App, Arg};
+use cursive::event::EventTrigger;
 use cursive::traits::Identifiable;
 use librespot_core::authentication::Credentials;
 use librespot_core::cache::Cache;
@@ -75,7 +76,7 @@ fn setup_logging(filename: &str) -> Result<(), fern::InitError> {
     Ok(())
 }
 
-fn credentials_prompt(error_message: Option<String>) -> Credentials {
+fn credentials_prompt(error_message: Option<String>) -> Result<Credentials, String> {
     if let Some(message) = error_message {
         let mut siv = cursive::default();
         let dialog = cursive::views::Dialog::around(cursive::views::TextView::new(format!(
@@ -87,7 +88,7 @@ fn credentials_prompt(error_message: Option<String>) -> Credentials {
         siv.run();
     }
 
-    authentication::create_credentials().expect("Could not create credentials")
+    authentication::create_credentials()
 }
 
 type UserData = Arc<UserDataInner>;
@@ -96,7 +97,7 @@ struct UserDataInner {
 }
 
 #[tokio::main]
-async fn main() {
+async fn main() -> Result<(), String> {
     let backends = {
         let backends: Vec<&str> = audio_backend::BACKENDS.iter().map(|b| b.0).collect();
         format!("Audio backends: {}", backends.join(", "))
@@ -122,6 +123,15 @@ async fn main() {
                 .help("custom basepath to config/cache files")
                 .takes_value(true),
         )
+        .arg(
+            Arg::with_name("config")
+                .short("c")
+                .long("config")
+                .value_name("FILE")
+                .help("Filename of config file in basepath")
+                .takes_value(true)
+                .default_value("config.toml"),
+        )
         .get_matches();
 
     if let Some(filename) = matches.value_of("debug") {
@@ -138,7 +148,9 @@ async fn main() {
 
     // Things here may cause the process to abort; we must do them before creating curses windows
     // otherwise the error message will not be seen by a user
-    let cfg: Arc<crate::config::Config> = Arc::new(Config::new());
+    let cfg: Arc<crate::config::Config> = Arc::new(Config::new(
+        matches.value_of("config").unwrap_or("config.toml"),
+    ));
 
     let cache = Cache::new(
         Some(config::cache_path("librespot")),
@@ -153,13 +165,13 @@ async fn main() {
                 info!("Using cached credentials");
                 c
             }
-            None => credentials_prompt(None),
+            None => credentials_prompt(None)?,
         }
     };
 
     while let Err(error) = spotify::Spotify::test_credentials(credentials.clone()) {
         let error_msg = format!("{}", error);
-        credentials = credentials_prompt(Some(error_msg));
+        credentials = credentials_prompt(Some(error_msg))?;
     }
 
     let mut cursive = cursive::default().into_runner();
@@ -218,13 +230,23 @@ async fn main() {
     // initial screen is library
     layout.set_screen("library");
 
-    cursive.add_global_callback(':', move |s| {
-        if s.find_name::<ContextMenu>("contextmenu").is_none() {
-            s.call_on_name("main", |v: &mut ui::layout::Layout| {
-                v.enable_cmdline();
-            });
-        }
-    });
+    let cmd_key = |cfg: Arc<Config>| cfg.values().command_key.unwrap_or(':');
+
+    {
+        let c = cfg.clone();
+        cursive.set_on_post_event(
+            EventTrigger::from_fn(move |event| {
+                event == &cursive::event::Event::Char(cmd_key(c.clone()))
+            }),
+            move |s| {
+                if s.find_name::<ContextMenu>("contextmenu").is_none() {
+                    s.call_on_name("main", |v: &mut ui::layout::Layout| {
+                        v.enable_cmdline(cmd_key(cfg.clone()));
+                    });
+                }
+            },
+        );
+    }
 
     cursive.add_global_callback('/', move |s| {
         if s.find_name::<ContextMenu>("contextmenu").is_none() {
@@ -257,22 +279,21 @@ async fn main() {
                 let mut main = s.find_name::<ui::layout::Layout>("main").unwrap();
                 main.clear_cmdline();
             }
+            let cmd_without_prefix = &cmd[1..];
             if cmd.strip_prefix('/').is_some() {
-                let query = &cmd[1..];
-                let command = Command::Jump(JumpMode::Query(query.to_string()));
+                let command = Command::Jump(JumpMode::Query(cmd_without_prefix.to_string()));
                 if let Some(data) = s.user_data::<UserData>().cloned() {
                     data.cmd.handle(s, command);
                 }
             } else {
-                let c = &cmd[1..];
-                let parsed = command::parse(c);
+                let parsed = command::parse(cmd_without_prefix);
                 if let Some(parsed) = parsed {
                     if let Some(data) = s.user_data::<UserData>().cloned() {
                         data.cmd.handle(s, parsed)
                     }
                 } else {
                     let mut main = s.find_name::<ui::layout::Layout>("main").unwrap();
-                    let err_msg = format!("Unknown command: \"{}\"", c);
+                    let err_msg = format!("Unknown command: \"{}\"", cmd_without_prefix);
                     main.set_result(Err(err_msg));
                 }
             }
@@ -305,4 +326,6 @@ async fn main() {
             }
         }
     }
+
+    Ok(())
 }
